vfbLib.parsers.truetype.TrueTypeStemsParser
===========================================

.. currentmodule:: vfbLib.parsers.truetype

.. autoclass:: TrueTypeStemsParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TrueTypeStemsParser.__init__
      ~TrueTypeStemsParser.parse
      ~TrueTypeStemsParser.parse_hex
      ~TrueTypeStemsParser.read_double
      ~TrueTypeStemsParser.read_doubles
      ~TrueTypeStemsParser.read_int16
      ~TrueTypeStemsParser.read_int32
      ~TrueTypeStemsParser.read_int8
      ~TrueTypeStemsParser.read_str
      ~TrueTypeStemsParser.read_str_all
      ~TrueTypeStemsParser.read_str_with_len
      ~TrueTypeStemsParser.read_uint16
      ~TrueTypeStemsParser.read_uint32
      ~TrueTypeStemsParser.read_uint8
      ~TrueTypeStemsParser.read_value
   
   

   
   
   